@@ -1,9 +1,10 @@
-from .excel_module import get_df,create_dataframe,get_row,get_cell_value
+from .excel_module import get_df,create_dataframe,get_row,get_cell_value,gpd
 from .functions import haversine
+from shapely.geometry import Polygon,MultiPolygon
 import os
 class landManager:
     _instance = None
-    def __init__(self,directory_js=None,default_polygon=None,column=None,value=None,default_index=1):
+    def __init__(self,directory_js=None,default_polygon=None,column=None,value=None,index=1):
         directory_js = directory_js or {}
         if landManager._instance is not None:
             raise Exception("This class is a singleton!")
@@ -19,10 +20,10 @@ class landManager:
             for file_item in os.listdir(directory_path):
                 item_path = os.path.join(directory_path,file_item)
                 self.file_manager[directory_name][os.path.splitext(file_item)[-1][1:]] = item_path
-        if self.default_polygon == None:
-            gdf=get_file_path(file_type='shp')
-            if gdf:
-                self.default_polygon = get_polygon(gdf,column=column,value=value,index=index)
+            if self.default_polygon == None:
+                gdf=self.get_contents(directory_name,file_type='shp')
+                if isinstance(gdf,gpd.GeoDataFrame):
+                    self.default_polygon = self.get_polygon(gdf,column=column,value=value,index=index)
     @staticmethod
     def get_instance(directory_js=None):
         if landManager._instance is None:
@@ -36,8 +37,8 @@ class landManager:
         if polygon:
             return polygon
         if column or value:
-            gdf,index = get_row(target_value=value,column_name=column,index_value=index,df=gdf)
-        if gdf:
+            gdf,index = get_row(target_value=value,column_name=column,df=gdf)
+        if isinstance(gdf,gpd.GeoDataFrame):
             return get_cell_value(gdf,'geometry',index)
     def get_file_path(self,dir_name,file_type):
         if dir_name == None:
