@@ -96,7 +96,7 @@ def get_df(source=None, nrows=None, header='infer', skiprows=None, condition=Non
     """
     if isinstance(source, (pd.DataFrame, gpd.GeoDataFrame)):
         logging.info("Data is already loaded as a DataFrame/GeoDataFrame.")
-        return filter_dataframe(source, nrows=nrows, condition=condition, indices=indices)
+        return filter_df(source, nrows=nrows, condition=condition, indices=indices)
 
     if source is None:
         logging.error("No source provided for loading data.")
@@ -120,7 +120,7 @@ def get_df(source=None, nrows=None, header='infer', skiprows=None, condition=Non
                 df = gpd.read_file(source)
             else:
                 raise ValueError(f"Unsupported file extension: {file_ext}")
-            return filter_dataframe(df, nrows=nrows, condition=condition, indices=indices)
+            return df
         except Exception as e:
             logging.error(f"Failed to read file: {e}")
             return None
@@ -129,7 +129,7 @@ def get_df(source=None, nrows=None, header='infer', skiprows=None, condition=Non
         try:
             logging.info(f"Reading from FileStorage: {secure_filename(source.filename)}")
             df = pd.read_excel(source.stream, nrows=nrows)
-            return filter_dataframe(df, nrows=nrows, condition=condition, indices=indices)
+            return df
         except Exception as e:
             logging.error(f"Failed to read from FileStorage: {e}")
             return None
@@ -137,12 +137,11 @@ def get_df(source=None, nrows=None, header='infer', skiprows=None, condition=Non
     if isinstance(source, (dict, list)):
         logging.info("Creating DataFrame from in-memory data structure.")
         df = pd.DataFrame(source)
-        return filter_dataframe(df, nrows=nrows, condition=condition, indices=indices)
-
+        return df
     logging.error("Invalid data source type provided.")
     return None
 
-def filter_dataframe(df, nrows=None, condition=None, indices=None):
+def filter_df(df, nrows=None, condition=None, indices=None):
     """
     Apply filtering to a DataFrame based on specified criteria.
 
